#
# spec file for package zeal
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zeal
Version:        0.6.1
Release:        1.1
Summary:        Offline API documentation browser
License:        GPL-3.0-only
Group:          Development/Tools/Other
Url:            https://zealdocs.org
Source0:        https://github.com/zealdocs/zeal/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# `help2man zeal > zeal.1` can't be run without X started.
Source9:        zeal.1
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Gui-private-headers-devel >= 5.2.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.2.0
BuildRequires:  pkgconfig(Qt5WebKitWidgets) >= 5.2.0
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Xml) >= 5.2.0
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xcb-keysyms)
Requires:       libQt5Sql5-sqlite >= 5.2.0
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files

%description
Zeal is an offline API documentation browser inspired by Dash
(OS X app).
 * Quickly search documentation using Alt+Space (or a customised)
   hotkey to display Zeal from any place in your workspace.
 * Search in multiple sets of documentation at once.
 * Don't be dependent on your internet connection.
 * Integrate Zeal with Emacs, Sublime Text, or Vim. See Usage »
   Editor plugins for details.

%prep
%setup -q

%build
%cmake -DBUILD_SHARED_LIBS:BOOL=OFF
%make_jobs

%install
%cmake_install
%suse_update_desktop_file -r org.zealdocs.Zeal Office Viewer
%fdupes -s %{buildroot}%{_datadir}

# Man pages:
mkdir -p %{buildroot}%{_mandir}/man1
cp %{SOURCE9} %{buildroot}%{_mandir}/man1

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%doc COPYING README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}
%{_datadir}/applications/org.zealdocs.Zeal.desktop
%{_datadir}/metainfo/org.zealdocs.Zeal.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}*

%changelog
* Fri Jan  4 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.6.1
  * Improvements:
    + Added Back/Forward to the webview's context menu.
    + Made search prefixes case insensitive.
    + Added Ctrl+L shortcut for focusing search input field.
    + Portable version now uses a relative path to the docset storage if it's a subdirectory.
  * Fixed Issues:
    + Fixed platform defined shortcut for preferences being ignored.
    + Fixed default fixed font size not saved.
    + Fixed broken JavaScript links.
    + Fixed make install not updating icon cache.
    + Set webview background color to white by default.
    + Fixed a problem preventing docset extraction to path containing non-Latin characters.
    + Fixed reproducibility of builds once again.
- desktop file has been renamed
- Add appdata.xml file
* Sun Feb 18 2018 jengelh@inai.de
- Trim other OS parts from documentation.
* Sun Feb 18 2018 avindra@opensuse.org
- Update to 0.6.0
  * New Features:
    + New in-page search toolbar.
    + Added default font preferences.
    + New welcome page had direct links for docset manager and
    application preferences.
    + Added option for choosing external link behavior.
  * Improvements:
    + Added option for enabling smooth scrolling.
    + Added Ctrl+, shortcut to open Preferences.
  * Fixed Issues:
    + Context menu now correctly states Open in new tab instead of
    window.
    + Fixed broken Open in new tab.
    + Fixed problem with ExtJS docset.
    + Added check for read-only docset storage.
- Includes 0.5.0
  * New Features:
    + Implemented update functionality for docsets installed via
    XML feeds.
  * Improvements:
    + Added show/hide options to the tray icon's menu.
    + Tabs are movable.
    + Double click on the tab bar creates a new tab.
    + Web view now has a predefined list of zooming level.
    + Linux: Use dedicated tray icon if theme provides one.
    + Portable version now indicates so in title of the main
    window.
  * Fixed Issues:
    + Fixed search result sorting with fuzzy search disabled.
    + Fixed invisible file operations preventing the Docsets
    dialog from closing.
    + Fixed crashing on some corrupted docset directories.
    + Fixed the app exiting on its own when a new version is
    available.
    + Windows: Fixed app not gaining focus when invoked from IDE
    plugins.
  * Known Issues:
    Open in new tab doesn't work.
- use https version of site
- switch to cmake, as qmake support was removed
- drop zeal-remove-qt-version.patch (no longer relevant)
- cleanup with spec-cleaner
* Sat Dec 16 2017 hpj@urpla.net
- Update to 0.4.0
  - New Features:
  - Added optional fuzzy search. (#100).
  - Added support for user-defined styles via custom CSS file.
    (#268)
  - Added support for a basic dark theme (webview only). (#466)
  - Added support for high resolution displays. (#111)
  - Switched to the CMake build system, support for qmake will be
    dropped shortly.
  - The minimally required Qt version bumped to 5.5.1.
  - As the result of above, libappindicator support is relies on
    the built-in Qt implementation.
  - Dropped support for Qt WebEngine.
  - Removed dependency on Qt Sql by using SQLite directly.
  - Windows binaries now bundle the new Qt WebKit, which fixes a
    lot of rendering and stability isses. (#359, #723)
  - Windows binaries are now 64-bit, and built with MSVC 2015.
  - Improvements:
  - New tabs now have the search box automatically focused. (#725)
  - Added a Retry button to the error box appearing on docset list
    download failure. (#566)
  - Updated welcome page style (includes a Carbon ad banner, which
    can be disabled in the settings).
  - Fixed Issues:
  - Fixed search for one-character terms. (#698)
  - Multiple fixes in the search algorithm. (#603, #650, #677)
  - Fixed navigation in some docsets. (#641)
  - Fixed portable version not saving docset storage path. (609)
  - Many rendering and stability issues fixed by switching to the
    new Qt WebKit. (#359, #723)
  - Fixed MSI installer not removing custom protocol handlers.
    (#755)
  - Known Issues:
  - Web pages using Fira Sans (e.g., PHP docset) font are rendered
    in italic. This is an upstream bug with Qt WebKit (#658)
- Build fixes
  - Added zeal-remove-qt-version.patch to remove Qt version check
    from qmake project
  - add sqlite3 build depedency
* Tue Oct 11 2016 dap.darkness@gmail.com
- Update to 0.3.1
  * Fixed random crashing on application start and exit. (#595)
  * Fixed web view hanging caused by URLs with no schema. (#532)
  * Fixed docset removal on Windows. (#621)
  * Fixed race condition (and warning) in docset removal logic.
  * Fixed docset selection with Select All shortcut (Ctrl+A).
* Sun Sep 25 2016 dap.darkness@gmail.com
- Update to 0.3.0
  * no upstream changes log.
- Deleted zeal-no-date-and-time.diff (can't find file to patch).
- Added man page via `help2man`.
* Sat May 21 2016 mpluskal@suse.com
- Update scriplet dependencies
- Use pretty name for url
- Use qmake5 macros when building
* Thu Nov 26 2015 idonmez@suse.com
- Remove unneeded appindicator dependency
* Thu Nov 26 2015 idonmez@suse.com
- Update to 0.2.1
  * Fixed issues:
    + Proxy settings lost after restart
    + Configuration file version not updated
    + Missing user agent header
    + Broken autocompletion for docset search keywords
* Sun Nov 15 2015 dap.darkness@gmail.com
- Updated to 0.2.0:
  * New features:
    + Added support for back/forward mouse buttons (#334),
    + Tabs can be closed with a middle click,
    + Ctrl/Shift+click  or middle click on a link
    opens it in a new tab (#403),
    + Implemented selective docset update and removal,
    + Added show and hide entries to the AppIndicator menu,
    + Now Zeal checks for updates on startup,
    + New dependency on X11 platforms: QtX11Extras;
  * Improvements:
    + Improved search performance by utilizing database indexes,
    + Previously selected tab becomes active
    when the current tab closes,
    + Download error message box now provides a retry option,
    + Improved search result list rendering performance (#211),
    + Improved global shortcut support on XCB platforms;
  * Fixed issues:
    + Drastically reduced memory consumption
    during docset download (#362, #394),
    + Fixed in-page search not hiding on Escape (#129),
    + Fixed AppIndicator support (#321),
    + Fixed minimize to tray (#325),
    + Fixed broken page navigation for ZDash docsets (#328),
    + Fixed wrong tab being closed on  Ctrl+W  (#329, #402),
    + Fixed ignored mouse clicks in search edit (#330),
    + Fixed search result sorting order (#407),
    + Fixed problem with missing keywords
    when parsing dash-plugin URI (#411),
    + Fixed global shortcut resets (#413),
    + Fixed crash on docset removal (#420).
* Mon Oct  5 2015 dap.darkness@gmail.com
- Updated to v0.1.1-117-g43ed784:
  * https://github.com/zealdocs/zeal/issues/376 was resolved
    (Fail to build with Qt5.5 affecting arm & leap 42.1).
* Thu May 21 2015 dap.darkness@gmail.com
- Updated to v0.1.1-52-g43ed784:
  * https://github.com/zealdocs/zeal/issues/333 was implemented.
- Fixed up zeal-no-date-and-time.diff a bit.
* Sun May 17 2015 dap.darkness@gmail.com
- Updated to 0.1.1:
  * Display a message box about in case old docset storage is found
  * Follow a new versioning scheme. (#203)
  * Added support for Dash protocols  dash:  and  dash-plugin:
    on Linux and Windows. (#247)
  * Revamped settings dialogue with more intuitive options.
  * Added a build option for portable mode ( qmake
    CONFIG+=portable ). In this case settings are stored in
    zeal.ini  next to the Zeal executable, and docset storage path
    defaults to  docsets  subdirectory. Changing docset storage
    path via the settings dialogue has only temporary effect, and
    it is not saved on application exit. It is still possible to
    set a permanent custom path by manually editing  zeal.ini .
  * Zeal now relies on its own server for obtaining docset list,
    rather than parsing Dash website.
  * Now the docset list is cached for 24 hours,
    but can be manually reloaded. (#287)
  * Implemented version check function
    ( Help  ->  Check for Update... ). (#282)
  * Improved display of docset download/unpack progress. (#252)
  * Now the main window of the running Zeal instance is brought up
    on attempt to start the app again. (#187)
  * Provided MSI installer for Windows users. (#279)
  * bugfixes, see more at https://github.com/zealdocs/zeal/releases
- Added %%desktop_database_post(un) & %%icon_theme_cache_post(un).
- Added zeal-no-date-and-time.diff  vs. file-contains-current-date.
- Qt >= 5.2.0 became required so oS <= 13.1 became unsupported.
* Thu Jan  8 2015 dap.darkness@gmail.com
- libQT5Sql5-sqlite has to be required, see more at
  https://github.com/zealdocs/zeal/issues/248.
* Sun Nov 23 2014 dap.darkness@gmail.com
- Updated to 20141123 git tag:
  * no upstream changelog.
* Sun Oct  5 2014 dap.darkness@gmail.com
- "I: Program returns random data in a function" were fixed.
* Thu Sep 25 2014 dap.darkness@gmail.com
- Initial build.
